# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

from importlib.metadata import version

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "pynetbox"
copyright = "2023, NetBox"
author = "Abhimanyu Saharan"
release = "Apache2"

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = ["sphinx.ext.autodoc"]

templates_path = ["_templates"]
exclude_patterns = ["_build"]

# The master toctree document.
master_doc = "index"

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "sphinx_rtd_theme"

htmlhelp_basename = "pynetboxdoc"

pygments_style = "sphinx"

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
# The full version, including alpha/beta/rc tags.
release_version = version("pynetbox")

#
# The short X.Y version.
version = ".".join(release_version.split(".")[:2])



import unittest
from unittest.mock import Mock

from pynetbox.core.query import Request


class RequestTestCase(unittest.TestCase):
    def test_get_openapi_version_less_than_3_5(self):
        test = Request("http://localhost:8080/api", Mock())
        test.get_version = Mock(return_value="3.4")

        # Mock the HTTP response
        response_mock = Mock()
        response_mock.ok = True
        test.http_session.get.return_value = response_mock

        test.get_openapi()
        test.http_session.get.assert_called_with(
            "http://localhost:8080/api/docs/?format=openapi",
            headers={"Accept": "application/json", "Content-Type": "application/json"},
        )

    def test_get_openapi_version_3_5_or_greater(self):
        test = Request("http://localhost:8080/api", Mock())
        test.get_version = Mock(return_value="3.5")

        # Mock the HTTP response
        response_mock = Mock()
        response_mock.ok = True
        test.http_session.get.return_value = response_mock

        test.get_openapi()
        test.http_session.get.assert_called_with(
            "http://localhost:8080/api/schema/",
            headers={"Accept": "application/json", "Content-Type": "application/json"},
        )



import unittest
from unittest.mock import patch

import pynetbox

nb = pynetbox.api("http://localhost:8000")


class DetailEndpointTestCase(unittest.TestCase):
    def test_detail_endpoint_create_single(self):
        # Prefixes
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"id": 123, "prefix": "1.2.3.0/24"},
        ):
            prefix_obj = nb.ipam.prefixes.get(123)
            self.assertEqual(prefix_obj.prefix, "1.2.3.0/24")
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"address": "1.2.3.1/24"},
        ):
            ip_obj = prefix_obj.available_ips.create()
            self.assertEqual(ip_obj.address, "1.2.3.1/24")
        # IP Ranges
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"id": 321, "display": "1.2.4.1-254/24"},
        ):
            ip_range_obj = nb.ipam.ip_ranges.get(321)
            self.assertEqual(ip_range_obj.display, "1.2.4.1-254/24")
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"address": "1.2.4.2/24"},
        ):
            ip_obj = ip_range_obj.available_ips.create()
            self.assertEqual(ip_obj.address, "1.2.4.2/24")

    def test_detail_endpoint_create_list(self):
        # Prefixes
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"id": 123, "prefix": "1.2.3.0/24"},
        ):
            prefix_obj = nb.ipam.prefixes.get(123)
            self.assertEqual(prefix_obj.prefix, "1.2.3.0/24")
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value=[{"address": "1.2.3.1/24"}, {"address": "1.2.3.2/24"}],
        ):
            ip_list = prefix_obj.available_ips.create([{} for _ in range(2)])
            self.assertTrue(isinstance(ip_list, list))
            self.assertEqual(len(ip_list), 2)
        # IP Ranges
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value={"id": 321, "display": "1.2.4.1-254/24"},
        ):
            ip_range_obj = nb.ipam.ip_ranges.get(321)
            self.assertEqual(ip_range_obj.display, "1.2.4.1-254/24")
        with patch(
            "pynetbox.core.query.Request._make_call",
            return_value=[{"address": "1.2.4.2/24"}, {"address": "1.2.4.3/24"}],
        ):
            ip_list = ip_range_obj.available_ips.create([{} for _ in range(2)])
            self.assertTrue(isinstance(ip_list, list))
            self.assertEqual(len(ip_list), 2)



import unittest
from unittest.mock import patch

import pynetbox

host = "http://localhost:8000"

def_kwargs = {
    "token": "abc123",
}


class AppConfigTestCase(unittest.TestCase):
    @patch(
        "pynetbox.core.query.Request.get",
        return_value={
            "tables": {
                "DeviceTable": {
                    "columns": [
                        "name",
                        "status",
                        "tenant",
                        "tags",
                    ],
                },
            },
        },
    )
    def test_config(self, *_):
        api = pynetbox.api(host, **def_kwargs)
        config = api.users.config()
        self.assertEqual(sorted(config.keys()), ["tables"])
        self.assertEqual(
            sorted(config["tables"]["DeviceTable"]["columns"]),
            ["name", "status", "tags", "tenant"],
        )


class PluginAppTestCase(unittest.TestCase):
    @patch(
        "pynetbox.core.query.Request.get",
        return_value=[
            {
                "name": "test_plugin",
                "package": "netbox_test_plugin",
            }
        ],
    )
    def test_installed_plugins(self, *_):
        api = pynetbox.api(host, **def_kwargs)
        plugins = api.plugins.installed_plugins()
        self.assertEqual(len(plugins), 1)
        self.assertEqual(plugins[0]["name"], "test_plugin")

    def test_plugin_app_name(self, *_):
        api = pynetbox.api(host, **def_kwargs)
        test_plugin = api.plugins.test_plugin
        self.assertEqual(test_plugin.name, "plugins/test-plugin")



from setuptools import find_packages, setup

setup(
    name="pynetbox",
    description="NetBox API client library",
    url="https://github.com/netbox-community/pynetbox",
    author="Zach Moody, Arthur Hanson",
    author_email="ahanson@netboxlabs.com",
    license="Apache2",
    include_package_data=True,
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    packages=find_packages(exclude=["tests", "tests.*"]),
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    install_requires=["requests>=2.20.0,<3.0", "packaging"],
    zip_safe=False,
    keywords=["netbox"],
    classifiers=[
        "Intended Audience :: Developers",
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
)
